##  Scope of Subtype Management
Conditional attribute settings are exclusively for attribute creation and for restricting visibility based on related field values. Hence, any other actions or modifications made on the fact sheet subtype configuration page is not limited to the selected subtype. For example, actions such as deleting a field or relation, changing translations, changing read-only or visibility settings, moving fields to other section / subsection, changing field type, size, or renderer, and changing field values still apply universally across all subtypes and the parent fact sheet.
YesNo
Send
